diff -waur doxygen-1.4.3.orig/src/groupdef.h doxygen-1.4.3/src/groupdef.h
--- doxygen-1.4.3.orig/src/groupdef.h	2005-02-28 02:40:12.000000000 +0000
+++ doxygen-1.4.3/src/groupdef.h	2005-07-19 18:19:18.405248000 +0100
@@ -147,6 +147,14 @@
 
 class GroupList : public QList<GroupDef>
 {
+ public:
+    virtual int compareItems(QCollection::Item i1, QCollection::Item i2)
+    {
+        const GroupDef *item1 = (GroupDef *)i1, *item2 = (GroupDef *)i2;
+
+        // Sort order is based on group names.  Could also be groupTitle().
+        return strcmp(item1->name().data(), item2->name().data());
+    }
 };
 
 class GroupListIterator : public QListIterator<GroupDef>
diff -waur doxygen-1.4.3.orig/src/latexgen.cpp doxygen-1.4.3/src/latexgen.cpp
--- doxygen-1.4.3.orig/src/latexgen.cpp	2005-05-17 03:40:16.000000000 +0100
+++ doxygen-1.4.3/src/latexgen.cpp	2005-07-19 18:57:21.408044800 +0100
@@ -656,6 +656,47 @@
       break;
     case isModuleDocumentation:
       {
+#ifndef DISABLE_LATEX_PAGE_SORT
+        GroupSDict::Iterator gli(Doxygen::groupSDict);
+        GroupList topgrps, procgrps;
+        GroupDef *gd;
+
+        // Close the heading
+        t << "}\n";
+
+        // Make a sorted list of GroupDef's that are not references or not sub-groups.
+        for (gli.toFirst();gd=gli.current();++gli)
+        {
+          if (!gd->isReference() && !gd->isASubGroup())
+          {
+              printf("Top level %s\n", (const char *)gd->name().data());
+              topgrps.inSort(gd);
+          }
+        }
+
+        // Check that a top level group was found
+        if(topgrps.isEmpty())
+        {
+          bool found = false;
+
+          for (gli.toFirst();(gd=gli.current()) && !found;++gli)
+          {
+            if(!gd->isReference())
+            {
+                found = true;
+            }
+          }
+
+          topgrps.append(gd);
+
+          warn(NULL, 0,
+               "Warning: No top level group found. Using %s as top level.",
+               gd->name().data());
+        }
+
+        // Recursively dump groups
+        listIncludeGroups(compactLatex, &topgrps, &procgrps);
+#else
         GroupSDict::Iterator gli(Doxygen::groupSDict);
         GroupDef *gd;
         bool found=FALSE;
@@ -675,6 +716,7 @@
             t << "{" << gd->getOutputFileBase() << "}\n";
           }
         }
+#endif
       }
       break;
     case isDirDocumentation:
@@ -1549,3 +1591,37 @@
   delete visitor; 
 }
 
+
+void LatexGenerator::listIncludeGroups(const bool compactLatex, const GroupList *gl, GroupList *procgrps)
+{
+  GroupListIterator  gli(*gl);
+  bool               first = procgrps->isEmpty();
+  GroupDef          *gd;
+
+  for (gli.toFirst();(gd=gli.current());++gli)
+  {
+    // Only include a file once incase of multiple groupings
+    if(!procgrps->contains(gd) && !gd->isReference())
+    {
+
+      if (compactLatex || first) t << "\\input"; else t << "\\include";
+      t << "{" << gd->getOutputFileBase() << "}\n";
+
+      // Mark group as processed
+      procgrps->append(gd);
+
+      GroupList *subGroups = gd->getSubGroups();
+
+      // Check for sub-groups
+      if(!subGroups->isEmpty())
+      {
+          subGroups->sort();
+          listIncludeGroups(compactLatex, subGroups, procgrps);
+      }
+
+      first = FALSE;
+    }
+  }
+}
+
+
diff -waur doxygen-1.4.3.orig/src/latexgen.h doxygen-1.4.3/src/latexgen.h
--- doxygen-1.4.3.orig/src/latexgen.h	2005-05-09 03:40:20.000000000 +0100
+++ doxygen-1.4.3/src/latexgen.h	2005-07-19 18:58:13.783356800 +0100
@@ -19,6 +19,7 @@
 #define LATEXGEN_H
 
 #include "outputgen.h"
+#include "groupdef.h"
 
 class QFile;
 
@@ -214,6 +215,9 @@
   private:
     LatexGenerator(const LatexGenerator &);
     LatexGenerator &operator=(const LatexGenerator &);
+
+    void listIncludeGroups(const bool compactLatex, const GroupList *gl, GroupList *procgrps);
+
     int col;
     bool insideTabbing;
     bool firstDescItem;
